==> haskell-logging-facade-0.3.0-46-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-mtwKmNoRXMLa5mLSx8YKq
key: logging-facade-0.3.0-mtwKmNoRXMLa5mLSx8YKq
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
abi: 4bfb284b711553c46105cf3aca8dbee2
exposed: True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
import-dirs: /usr/lib/ghc-8.6.5/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-mtwKmNoRXMLa5mLSx8YKq
depends:
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.0-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-9eq87y7CWic1v8LUVMy4MF
key: logging-facade-0.3.0-9eq87y7CWic1v8LUVMy4MF
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
abi: a598f9a50bbf47e252cf7d7a5405ce47
exposed: True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
import-dirs: /usr/lib/ghc-8.6.5/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-9eq87y7CWic1v8LUVMy4MF
depends:
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
